@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta::Converter;
 
-our $VERSION = '2.150006'; # TRIAL
+our $VERSION = '2.150007'; # TRIAL
 
 #pod =head1 SYNOPSIS
 #pod
@@ -66,9 +66,9 @@ sub _dclone {
   }
 
   # We can't know if TO_JSON gives us cloned data, so refs must recurse
-  if ( $ref->can('TO_JSON') ) {
+  if ( eval { $ref->can('TO_JSON') } ) {
     my $data = $ref->TO_JSON;
-    return ref $data ? _dclone( $ref->TO_JSON ) : $data;
+    return ref $data ? _dclone( $data ) : $data;
   }
 
   # Just stringify everything else
@@ -1513,7 +1513,7 @@ CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.150006
+version 2.150007
 
 =head1 SYNOPSIS
 
