@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta::Validator;
 
-our $VERSION = '2.150006'; # TRIAL
+our $VERSION = '2.150007'; # TRIAL
 
 #pod =head1 SYNOPSIS
 #pod
@@ -669,8 +669,8 @@ sub check_list {
 #pod
 #pod boolean($self,$key,$value)
 #pod
-#pod Validates for a boolean value. Currently these values are '1', '0', 'true',
-#pod 'false', however the latter 2 may be removed.
+#pod Validates for a boolean value: a defined value that is either "1" or "0" or
+#pod stringifies to those values.
 #pod
 #pod =item *
 #pod
@@ -833,7 +833,7 @@ sub version {
 sub boolean {
     my ($self,$key,$value) = @_;
     if(defined $value) {
-        return 1    if($value =~ /^(0|1|true|false)$/);
+        return 1    if($value =~ /^(0|1)$/);
     } else {
         $value = '<undef>';
     }
@@ -996,7 +996,7 @@ CPAN::Meta::Validator - validate CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.150006
+version 2.150007
 
 =head1 SYNOPSIS
 
@@ -1124,8 +1124,8 @@ are both valid. A leading 'v' like 'v1.2.3' is also valid.
 
 boolean($self,$key,$value)
 
-Validates for a boolean value. Currently these values are '1', '0', 'true',
-'false', however the latter 2 may be removed.
+Validates for a boolean value: a defined value that is either "1" or "0" or
+stringifies to those values.
 
 =item *
 
